flake8-badbear
===========

flake8 plugin which checks common error-prone code


## installation

```bash
pip install flake8-badbear
```

## flake8 codes

| Code   | Description                                            |
|--------|--------------------------------------------------------|
| BB001 | 'Prone to Error "NoneType" object is not iterable. Check None or list length.'              |